# coding=utf-8

from .downloadhelper import Download
from .downloadhelper import MultiDownloadThread
from .downloadhelper import VERSION

download_class = Download

def download(url, file_name, file_path=None, id=1, ids=1):
    """
    download main
    return (all_size, need_download_size, flag)
    flag:
        0  Success, download
        1  Success, and alread downloaded
        2  Success, and modified , then redownload
        -1 Failed, and Request but not response
        -2 Failed, and connection Error
        -3 Failed, and Request Times Out; Default Times = Twice(2)
        -4 Failed, and downloading then socket.timeout

    For Example:
        a = download(url, file_name[, id, ids])
        print(a)
        help(a)
    """
    oo = Download()
    return oo.download(url, file_name, file_path, id, ids)

def multidownload(url, file_name, file_path, id=1, ids=1):
    """
        multiple threads download
    """
    oo = MultiDownloadThread()
    return oo.download(url, file_name, file_path, id, ids)        



#!/usr/bin/env python
# coding=utf-8
import os
import sys

import downloadhelper

try:
    from setuptools import setup, find_packages
except ImportError:
    from distutils.core import setup

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

packages = [
    'downloadhelper',
]

requires = [
    'requests',
]

try:
    with open('README.rst', 'r') as f:
        readme = f.read()
except :
    readme = ''
try:
    with open('HISTORY.rst', 'r') as f:
        history = f.read()
except :
    history = ''

setup(
    name='downloadhelper',
    version=downloadhelper.VERSION,
    description='Python Download Helper',
    long_description=readme + '\n\n' + history,
    author='Cole Smith',
    author_email='uniquecolesmith@gmail.com',
    url='',
    packages=packages,
    package_data={'': ['LICENSE', 'NOTICE'], 'downloadhelper': ['*.pem']},
    package_dir={'downloadhelper': 'downloadhelper'},
    include_package_data=True,
    install_requires=requires,
    license='Apache 2.0',
    zip_safe=False,
    classifiers=(
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4'
    ),
    extras_require={
        'secuirity': ['pyOpenSSL', 'ndg-httpsclient', 'pyasn1'],
    },
)
